.. _APIReferenceAppsDiffusion:

Apps Diffusion API Reference
============================

The diffusion module has been tested with MRI data from some major vendors.

Module imagedata.apps.diffusion
----------------------------------------
.. automodule:: imagedata.apps.diffusion
    :members:
